
/* GKrellM Powerbook PMU plugin 
|  Battery monitor using PMUD for Apple Powerbooks running Linux/PMac
|  Copyright (C) 2000  Joseph Palani Garcia
|  Author:   Joseph Palani Garcia jpgarcia@execpc.com
|  Version:  0.11
|  Latest versions might be found at:  http://www.execpc.com/~jpgarcia
|  or by following links from the GKrellM homepage at: http://gkrellm.net
|
|  This program is free software which I release under the GNU General Public
|  License. You may redistribute and/or modify this program under the terms
|  of that license as published by the Free Software Foundation; either
|  version 2 of the License, or (at your option) any later version.
|
|  This program is distributed in the hope that it will be useful,
|  but WITHOUT ANY WARRANTY; without even the implied warranty of
|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
|  GNU General Public License for more details.
|
|  To get a copy of the GNU General Public License,  write to the
|  Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "../pmu_user.h"
#include "gkrellm_pmu.h"

gchar *model[] = {
     N_("unknown (and unsupported)"),	// 0
     N_("unknown (and unsupported)"),	// 1
     N_("unknown (and unsupported)"),	// 2
     N_("unknown (and unsupported)"),	// 3
     N_("unknown (and unsupported)"),	// 4
     N_("unknown (and unsupported)"),	// 5
     N_("unknown (and unsupported)"),	// 6
     N_("unknown (and unsupported)"),	// 7
     N_("unknown (and unsupported)"),	// 8
     N_("2400/3400/3500 (untested)"),	// 9
     N_("G3 Wallstreet/PDQ"),	// 10
     N_("1999 G3 Lombard"),	// 11
     N_("iBook (untested)"),	// 12
     N_("something nice (but unsupported)")	// > 12
};

void
init_pmu_struct ()
{
     sys_pmu.b[1].available = sys_pmu.b[0].available = BATT_NA;
     sys_pmu.b[1].current = sys_pmu.b[0].current =
	  sys_pmu.b[1].percentage = sys_pmu.b[0].percentage =
	  sys_pmu.b[1].charging = sys_pmu.b[0].charging =
	  sys_pmu.time_left = sys_pmu.nbattery = sys_pmu.low_second_krell =
	  sys_pmu.left_enabled = 0;
     sys_pmu.visible = TRUE;
     sys_pmu.version = -1;
     sys_pmu.ac_is_on_line = sys_pmu.use_memory_style = 1;
}

int
init_pmu ()
{
     unsigned char vers;
     char c[100];
     float pmud_ver;

     pmud_socket (1);

     if (!sys_pmu.pmud.open)
	  return 0;

     read (sys_pmu.pmud.sock, c, 100);
     strtok (c, PMUD_INPUT_DELIM);
     pmud_ver = atof (strtok (0, PMUD_INPUT_DELIM));
     vers = atoi (strtok (0, PMUD_INPUT_DELIM));

     sys_pmu.version = vers;
     switch (vers) {
	  case PMU_VERSION_WALLSTREET:
	  case PMU_VERSION_LOMBARD:
	  sys_pmu.nbattery = 2;
	  sys_pmu.read_pmu = read_g3_pmu;
	  break;
	  case PMU_VERSION_OHARE:
	  sys_pmu.nbattery = 1;
	  sys_pmu.read_pmu = read_ohare_pmu;
	  break;
	  case PMU_VERSION_KEYLARGO:
	  sys_pmu.nbattery = 1;
	  sys_pmu.read_pmu = read_g3_pmu;
	  break;
	  default:
	  pmud_socket (0);
	  return 0;
     }
     sprintf (sys_pmu.pmu_info, _("PMUD: %.1f   Model: %s   Batt: %i"), pmud_ver,
	  model[(vers < 13) ? vers : 13], sys_pmu.nbattery);

     (*(sys_pmu.read_pmu)) ();
     return (sys_pmu.nbattery > 0);
}

void
update_pmu ()
{
     int c;

     if (GK.five_second_tick) {
	  (*(sys_pmu.read_pmu)) ();

	  c = ((sys_pmu.left_enabled) && (sys_pmu.nbattery == 2)
	       && (sys_pmu.b[1].available == BATT_NO));
	  if (c != sys_pmu.left_mode_on) {
	       sys_pmu.left_mode_on = c;
	       gkrellm_enable_visibility (FALSE, &sys_pmu.visible, pmu->hbox, pmu->h);
	       create_pmu (sys_pmu.vbox, 0);
	       gkrellm_enable_visibility (TRUE, &sys_pmu.visible, pmu->hbox, pmu->h);
	  }
	  if ((sys_pmu.nbattery == 1) || (sys_pmu.left_mode_on)) {
	       if (sys_pmu.b[0].available == BATT_NO)
		    sys_pmu.draw_current = 0;
	  }

	  update_battery_decals ();
	  update_text_decals ();
	  update_krells ();

	  gkrellm_draw_layers (pmu);
     }
}

Monitor monitor_pmu = {
     N_("PMU"),
     0,
     create_pmu,
     update_pmu,
     create_pmu_tab,
     apply_pmu_config,

     save_pmu_config,
     load_pmu_config,
     PMU_CONFIG_KEYWORD,

     NULL,
     NULL,
     NULL,

     GKRELLM_PMU_LOCATION,

     NULL,
     NULL
};

Monitor *
init_plugin (void)
{
     init_pmu_struct ();
     if (init_pmu ())
	  return &monitor_pmu;
     else
	  return NULL;
}
