
/* GKrellM Powerbook PMU plugin 
|  Battery monitor using PMUD for Apple Powerbooks running Linux/PMac
|  Copyright (C) 2000  Joseph Palani Garcia
|  Author:   Joseph Palani Garcia jpgarcia@execpc.com
|  Version:  0.11
|  Latest versions might be found at:  http://www.execpc.com/~jpgarcia
|  or by following links from the GKrellM homepage at: http://gkrellm.net
|
|  This program is free software which I release under the GNU General Public
|  License. You may redistribute and/or modify this program under the terms
|  of that license as published by the Free Software Foundation; either
|  version 2 of the License, or (at your option) any later version.
|
|  This program is distributed in the hope that it will be useful,
|  but WITHOUT ANY WARRANTY; without even the implied warranty of
|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
|  GNU General Public License for more details.
|
|  To get a copy of the GNU General Public License,  write to the
|  Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#define PACKAGE "gkrellm_pmu"

#include <gkrellm/gkrellm.h>
#include <unistd.h>

#define GKRELLM_PMU_VERSION_MAJOR 0
#define GKRELLM_PMU_VERSION_MINOR 11
#define GKRELLM_PMU_VERSION_TYPE  ""

typedef struct {
     gint available;
     gint current;
     gint percentage;
     gint charging;
     Krell *krell;
     Decal *icon;
     Decal *modif;
     Decal *text;
} pmu_battery;

typedef struct {
     int open;
     int sock;
} pmud_socket_type;

typedef struct {
     int version;
     int nbattery;
     pmu_battery b[2];
     gint time_left;
     gint ac_is_on_line;
     void (*read_pmu) ();
     gint low_second_krell;
     gint use_memory_style;
     gint visible;
     gint left_mode_on;
     gint left_enabled;
     gint draw_current;
     gint show_charge_time;
     pmud_socket_type pmud;
     char pmu_info[50];
     GtkWidget *vbox;
} _sys_pmu;

enum { BATT_NO, BATT_LOW, BATT_OK, BATT_FULL,
     BATT_CHARGE, BATT_USE, BATT_AC, BATT_NA, BATT_YES
};

#define BATT_NDECALS BATT_YES

#define PMU_VERSION_OHARE	    9
#define PMU_VERSION_WALLSTREET	10
#define PMU_VERSION_LOMBARD	    11
#define PMU_VERSION_KEYLARGO	12

#define PMU_CONFIG_KEYWORD "pmu"

#define PMUD_INPUT_DELIM " \t\n"

#define VERT_MARGIN 1
#define HORIZ_MARGIN 2

extern void update_pmu ();
extern void update_krells ();
extern void update_text_decals ();
extern void update_battery_decals ();
extern void create_pmu_krells ();
extern void create_pmu (GtkWidget * vbox, gint first_create);
extern void pmud_socket (int open);
extern void save_pmu_config (FILE * f);
extern void load_pmu_config (gchar * arg);
extern void apply_pmu_config ();
extern void create_pmu_tab (GtkWidget * tab_vbox);
extern void read_g3_pmu ();
extern void read_ohare_pmu ();
extern int get_current ();

extern Panel *pmu;
extern _sys_pmu sys_pmu;
