/* GKrellM Powerbook PMU plugin 
|  Battery monitor using PMUD for Apple Powerbooks running Linux/PMac
|  Copyright (C) 2000  Joseph Palani Garcia
|  Author:   Joseph Palani Garcia jpgarcia@execpc.com
|  Version:  0.11
|  Latest versions might be found at:  http://www.execpc.com/~jpgarcia
|  or by following links from the GKrellM homepage at: http://gkrellm.net
|
|  This program is free software which I release under the GNU General Public
|  License. You may redistribute and/or modify this program under the terms
|  of that license as published by the Free Software Foundation; either
|  version 2 of the License, or (at your option) any later version.
|
|  This program is distributed in the hope that it will be useful,
|  but WITHOUT ANY WARRANTY; without even the implied warranty of
|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
|  GNU General Public License for more details.
|
|  To get a copy of the GNU General Public License,  write to the
|  Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "gkrellm_pmu.h"

gchar *info_text[] = {
     N_("GKrellM PMU creates a battery display for Apple Powerbook\n"),
     N_("users without using APM hacks, which tend to be less verbose.  This\n"),
     N_("plugin requires PMUD be already running on your system.  This plugin\n"),
	 N_("doesnt support all systems, which I would like to remedy.\n"),
	 N_("Since I don't have access to all models, I release untested code in\n"),
	 N_("hopes that it will work or someone will tell me that it doesn't.  If your\n"),
	 N_("system is unsupported or under-supported, feel free to contact me.  Sorry\n"),
	 N_("about any inconveniences in this method.\n\n"),
     N_("<b>Interface Description\n"),
     N_("On the left is a battery decal similar to those used in the Control\n"),
     N_("Strip.  The battery will change color by current charge, this being\n"),
     N_("<i>\tGreen\t-\t100%\n"),
     N_("<i>\tBlue\t-\t20-100%\n"),
     N_("<i>\tRed\t-\t<20%\n"),
     N_("<i>\tGrey\t-\tnot installed(and not plugged in)\n"),
     N_("The percent is also shown in detail using a Krell meter.\n"),
     N_("Also, additional icons are shown for status:\n"),
     N_("<i>\tBolt\t-\tcharging\n"),
     N_("<i>\tCord\t-\tplugged in (and not charging)\n"),
     N_("<i>\t+/-\t-\tin use\n"),
     N_("On the right are more detail status displays.\n"),
     N_("<i>\tTotal time remaining (-:-- when inactive)\n"),
     N_("<i>\tDraw in milliAmps. (negative is in use, positive is charging)\n"),
     N_("If two batteries are displayed, both time and current are shown.\n"),
     N_("Otherwise only one is shown, and can be switched by clicking on the\n"),
     N_("area. (with a few exceptions)\n\n\n"),
     N_("<b>Configurable Options: \n\n"),
     N_("<b>[Memory/Swap Krell style]\n"),
     N_("Use the krell styles used with memory and swap krells\n"),
     N_("If this is not checked, filesystem styles will be used\n\n"),
     N_("<b>[Show Charge time]\n"),
     N_("If this is set, the time display shows time remaining when charging\n"),
     N_("rather than remaining inactive.  For those really impatient people who\n"),
     N_("absolutely must know.  Its only an estimate anyway. :P\n\n"),
     N_("<b>[Force Second Battery's Krell to bottom] (dual battery systems only)\n"),
     N_("For some krell styles, it is preffered that the krell is at the bottom\n"),
     N_("of the bounding box rather than at the top.  Check this to force it to\n"),
     N_("the bottom.  Useful for inverted Swap krells, or when the krell displays\n"),
     N_("off the bottom due to short battery status decals\n\n"),
     N_("<b>[Enable Left-only Display] (dual battery systems only)\n"),
     N_("When enabled, if the right battery is not available, the monitor does\n"),
     N_("not display status of the right battery. (single battery mode)\n\n")
};

void
save_pmu_config (FILE * f)
{
     fprintf (f, "%s use_memory_style %d\n", PMU_CONFIG_KEYWORD, sys_pmu.use_memory_style);
     fprintf (f, "%s show_charge_time %d\n", PMU_CONFIG_KEYWORD, sys_pmu.show_charge_time);
     fprintf (f, "%s second_too_high %d\n", PMU_CONFIG_KEYWORD, sys_pmu.low_second_krell);
     fprintf (f, "%s left_condense %d\n", PMU_CONFIG_KEYWORD, sys_pmu.left_enabled);
}

void
load_pmu_config (gchar * arg)
{
     gchar config[64], item[512];

     if (sscanf (arg, "%s %[^\n]", config, item) == 2) {
	  if (strcmp (config, "use_memory_style") == 0)
	       sscanf (item, "%d", &sys_pmu.use_memory_style);
	  else if (strcmp (config, "show_charge_time") == 0)
	       sscanf (item, "%d", &sys_pmu.show_charge_time);
	  else if (strcmp (config, "second_too_high") == 0)
	       sscanf (item, "%d", &sys_pmu.low_second_krell);
	  else if (strcmp (config, "left_condense") == 0)
	       sscanf (item, "%d", &sys_pmu.left_enabled);
     }
}


GtkWidget *low_second_krell_button;
GtkWidget *style_button;
GtkWidget *charge_button;
GtkWidget *left_mode_button;

void
apply_pmu_config ()
{
     gint new;
     int modified_krells = 0;

     if (low_second_krell_button) {
	  new = GTK_TOGGLE_BUTTON (low_second_krell_button)->active;
	  if (sys_pmu.low_second_krell != new) {
	       sys_pmu.low_second_krell = new;
	       modified_krells = 1;
	  }
     }
     if (charge_button)
	  sys_pmu.show_charge_time = GTK_TOGGLE_BUTTON (charge_button)->active;

     if (left_mode_button)
	  sys_pmu.left_enabled = GTK_TOGGLE_BUTTON (left_mode_button)->active;
     if (style_button) {
	  new = GTK_TOGGLE_BUTTON (style_button)->active;
	  if (sys_pmu.use_memory_style != new) {
	       sys_pmu.use_memory_style = new;
	       modified_krells = 1;
	  }
     }
     if (modified_krells) {
	  create_pmu_krells ();

	  update_krells ();
	  gkrellm_draw_layers (pmu);
     }
}

void
create_pmu_tab (GtkWidget * tab_vbox)
{
     GtkWidget *notebk, *table, *vbox, *frame, *label, *about, *helpwin, *text;
     gchar *buf;

     notebk = gtk_notebook_new ();
     gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebk), GTK_POS_TOP);
     gtk_box_pack_start (GTK_BOX (tab_vbox), notebk, TRUE, TRUE, 0);

     frame = gtk_frame_new (NULL);
     gtk_container_border_width (GTK_CONTAINER (frame), 3);

     vbox = gtk_vbox_new (FALSE, 0);
     gtk_container_border_width (GTK_CONTAINER (vbox), 3);

     about = gtk_label_new (sys_pmu.pmu_info);
     gtk_box_pack_start (GTK_BOX (vbox), about, TRUE, TRUE, 0);
     style_button = gtk_check_button_new_with_label (_("Memory/Swap Krell style"));
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (style_button), sys_pmu.use_memory_style);
     gtk_box_pack_start (GTK_BOX (vbox), style_button, TRUE, TRUE, 0);

     charge_button = gtk_check_button_new_with_label (_("Show Charge time"));
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (charge_button),
	  sys_pmu.show_charge_time);
     gtk_box_pack_start (GTK_BOX (vbox), charge_button, TRUE, TRUE, 0);

     if (sys_pmu.nbattery > 1) {
	  low_second_krell_button =
	       gtk_check_button_new_with_label (_("Force Second Battery's Krell to bottom"));
	  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (low_second_krell_button),
	       sys_pmu.low_second_krell);
	  gtk_box_pack_start (GTK_BOX (vbox), low_second_krell_button, TRUE, TRUE, 0);
	  left_mode_button = gtk_check_button_new_with_label (_("Enable Left-only display"));
	  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (left_mode_button),
	       sys_pmu.left_enabled);
	  gtk_box_pack_start (GTK_BOX (vbox), left_mode_button, TRUE, TRUE, 0);
     }
     table = gtk_table_new (0, 3, FALSE);
     gtk_table_set_col_spacings (GTK_TABLE (table), 2);
     gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 2);

     label = gtk_label_new (_("Options"));

     gtk_container_add (GTK_CONTAINER (frame), vbox);
     gtk_notebook_append_page (GTK_NOTEBOOK (notebk), frame, label);
     frame = gtk_frame_new (NULL);
     gtk_container_border_width (GTK_CONTAINER (frame), 3);

     helpwin = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (helpwin),
	  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     gtk_container_add (GTK_CONTAINER (frame), helpwin);

     text = gtk_text_new (NULL, NULL);

     gkrellm_add_info_text (text, info_text, sizeof (info_text) / sizeof (gchar *));

     gtk_text_set_editable (GTK_TEXT (text), FALSE);
     gtk_container_add (GTK_CONTAINER (helpwin), text);

     label = gtk_label_new (_("Info"));
     gtk_notebook_append_page (GTK_NOTEBOOK (notebk), frame, label);

     buf = g_strdup_printf (_("GKrellM PMU v%i.%i%s\n"
	       "GKrellM Powerbook Battery Monitor\n\n"
	       "Copyright (C) 2000 Joseph P. Garcia\n"
	       "jpgarcia@execpc.com\n"
	       "http://www.execpc.com/~jpgarcia\n\n"
	       "Released under the GNU Public License\n"),
	  GKRELLM_PMU_VERSION_MAJOR,
	  GKRELLM_PMU_VERSION_MINOR, GKRELLM_PMU_VERSION_TYPE);
     /* About */
     about = gtk_label_new (buf);
     g_free (buf);
     label = gtk_label_new (_("About"));
     gtk_notebook_append_page (GTK_NOTEBOOK (notebk), about, label);
}
