
/* GKrellM Powerbook PMU plugin 
|  Battery monitor using PMUD for Apple Powerbooks running Linux/PMac
|  Copyright (C) 2000  Joseph Palani Garcia
|  Author:   Joseph Palani Garcia jpgarcia@execpc.com
|  Version:  0.11
|  Latest versions might be found at:  http://www.execpc.com/~jpgarcia
|  or by following links from the GKrellM homepage at: http://gkrellm.net
|
|  This program is free software which I release under the GNU General Public
|  License. You may redistribute and/or modify this program under the terms
|  of that license as published by the Free Software Foundation; either
|  version 2 of the License, or (at your option) any later version.
|
|  This program is distributed in the hope that it will be useful,
|  but WITHOUT ANY WARRANTY; without even the implied warranty of
|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
|  GNU General Public License for more details.
|
|  To get a copy of the GNU General Public License,  write to the
|  Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "gkrellm_pmu.h"
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>

#define PMUD_HOST "localhost"
#define PMUD_PORT 879

int
open_pmud_socket ()
{
     struct hostent *hostip;
     struct sockaddr_in server;
     int ret;
     int tries;

     if (!(hostip = gethostbyname (PMUD_HOST)))
	  return -1;
     server.sin_family = AF_INET;
     memcpy (&server.sin_addr.s_addr, hostip->h_addr, sizeof (server.sin_addr.s_addr));
     server.sin_port = htons (PMUD_PORT);

     for (tries = 5; tries > 0; tries--) {
	  ret = socket (AF_INET, SOCK_STREAM, 0);
	  if (ret < 0) {
	       usleep (10);
	       tries--;
	       continue;
	  }
	  if (connect (ret, (struct sockaddr *) &server, sizeof (server)) < 0) {
	       close (ret);
	       usleep (10);
	       tries--;
	       continue;
	  }
	  return ret;
     }
     return -1;
}

void
pmud_socket (int open)
{
     if (sys_pmu.pmud.open == open)
	  return;
     sys_pmu.pmud.open = open;
     if (open) {
	  if (-1 == (sys_pmu.pmud.sock = open_pmud_socket ()))
	       sys_pmu.pmud.open = 0;
     } else {
	  close (sys_pmu.pmud.sock);
	  sys_pmu.pmud.open = 0;
     }
}
